==> spip_4.0.4.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reset',
	'boxstr_close' => 'Close',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Dialogue box',
	'boxstr_dialog_title_medias' => 'Media display',
	'boxstr_loading' => 'Loading…',
	'boxstr_next' => 'Next',
	'boxstr_press_escape_to_close' => 'Press ’Esc’ to close',
	'boxstr_previous' => 'Previous',
	'boxstr_slideshowStart' => 'Slideshow',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Specify the target element that will trigger the box. (jQuery or CSS expression)',
	'explication_selecteur_galerie' => 'Specify the target elements to group together into a gallery. (jQuery or CSS expression)',
	'explication_splash_url' => 'Enter the URL of the media to automatically display in a box on the first visit to the public site.',
	'explication_traiter_toutes_images' => 'Insert a box around all images?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Black default',
	'info_box_lity_nom_skin__simple_white' => 'Light default',
	'info_box_lity_nom_skin_fancybox' => 'Fancybox way',
	'info_box_lity_nom_skin_thickbox' => 'Thickbox way',

	// L
	'label_active' => 'Activate mediabox on the public site',
	'label_apparence' => 'Appearance',
	'label_aucun_style' => 'Do not use any frame by default',
	'label_choix_transition_elastic' => 'Elastic',
	'label_choix_transition_fade' => 'Fade',
	'label_choix_transition_none' => 'Without transition effect',
	'label_maxheight' => 'Max height (% or px)',
	'label_maxwidth' => 'Max width (% or px)',
	'label_minheight' => 'Min height (% or px)',
	'label_minwidth' => 'Min width (% or px)',
	'label_opacite' => 'Background opacity',
	'label_selecteur_commun' => 'In general',
	'label_selecteur_galerie' => 'In gallery mode',
	'label_skin' => 'Visual skin',
	'label_slideshow_speed' => 'Exhibition time of the slideshow images (ms)',
	'label_speed' => 'Transition speed (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Height (% or px)',
	'label_splash_url' => 'URL to display',
	'label_splash_width' => 'Width (% or px)',
	'label_traiter_toutes_images' => 'Pictures',
	'label_transition' => 'Transition between two views',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configuration of the Media box'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reset',
	'boxstr_close' => 'Close',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Dialogue box',
	'boxstr_dialog_title_medias' => 'Media display',
	'boxstr_loading' => 'Loading…',
	'boxstr_next' => 'Next',
	'boxstr_press_escape_to_close' => 'Press ’Esc’ to close',
	'boxstr_previous' => 'Previous',
	'boxstr_slideshowStart' => 'Slideshow',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Specify the target element that will trigger the box. (jQuery or CSS expression)',
	'explication_selecteur_galerie' => 'Specify the target elements to group together into a gallery. (jQuery or CSS expression)',
	'explication_splash_url' => 'Enter the URL of the media to automatically display in a box on the first visit to the public site.',
	'explication_traiter_toutes_images' => 'Insert a box around all images?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Black default',
	'info_box_lity_nom_skin__simple_white' => 'Light default',
	'info_box_lity_nom_skin_fancybox' => 'Fancybox way',
	'info_box_lity_nom_skin_thickbox' => 'Thickbox way',

	// L
	'label_active' => 'Activate mediabox on the public site',
	'label_apparence' => 'Appearance',
	'label_aucun_style' => 'Do not use any frame by default',
	'label_choix_transition_elastic' => 'Elastic',
	'label_choix_transition_fade' => 'Fade',
	'label_choix_transition_none' => 'Without transition effect',
	'label_defaultcaptionstate' => 'Image caption ',
	'label_defaultcaptionstate_expanded' => 'Complete',
	'label_defaultcaptionstate_min' => 'Shorted',
	'label_maxheight' => 'Max height (% or px)',
	'label_maxwidth' => 'Max width (% or px)',
	'label_minheight' => 'Min height (% or px)',
	'label_minwidth' => 'Min width (% or px)',
	'label_opacite' => 'Background opacity',
	'label_selecteur_commun' => 'In general',
	'label_selecteur_galerie' => 'In gallery mode',
	'label_skin' => 'Visual skin',
	'label_slideshow_speed' => 'Exhibition time of the slideshow images (ms)',
	'label_speed' => 'Transition speed (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Height (% or px)',
	'label_splash_url' => 'URL to display',
	'label_splash_width' => 'Width (% or px)',
	'label_traiter_toutes_images' => 'Pictures',
	'label_transition' => 'Transition between two views',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configuration of the Media box'
);
